#!/usr/bin/env bash

extract_sensor_rpm() { (
    set -e
    local rpm_name=$1 tempdir=$2

    cd "${tempdir}"
    cp "/sensors/rpms/${rpm_name}" "${tempdir}"
    rpm2cpio ./*.rpm | cpio -idm
    if [ -d "${tempdir}/tmp/cbinstaller" ]; then
        cp -fa "${tempdir}"/tmp/cbinstaller/* /sensors/installers/osx
    else
        cp -fa "${tempdir}"/usr/share/cb/coreservices/installers/* /sensors/installers
    fi
); }

install_new_sensors() {
    if compgen -G "/sensors/rpms/*.rpm" > /dev/null; then
        echo "Detected new sensor installer rpm files"

        local rpm_name rpm_path
        for rpm_path in /sensors/rpms/*.rpm; do
            rpm_name=$(basename "${rpm_path}")
            echo "Installing ${rpm_name}"

            if rpm -qlp "${rpm_path}" 2>&1 | grep -q "/usr/share/cb/coreservices/installers/\|/tmp/cbinstaller/"; then
                local tempdir
                tempdir=$(mktemp -d)

                extract_sensor_rpm "${rpm_name}" "${tempdir}"
                local exit_status=$?
                if [ ${exit_status} -eq 0 ]; then
                    rm "${rpm_path}"
                fi
                rm -rf "${tempdir}"
            else
                echo "Error: ${rpm_name} is not a valid sensor installer rpm"
            fi
        done

        printf "Finished scanning for new sensor installer rpm files\n\n"
    fi
}

main() {
    # If there are any new installers in this image, make them available on the host.
    cp -na /usr/share/cb/setup/sensor-installers/* /sensors/installers

    install_new_sensors
    if [ "$1" == "--update" ]; then
        /usr/share/cb/cbcheck sensor-builds --update
    fi
}

main "$@"
